@@ -3,7 +3,7 @@ from kabaret.flow_entities.entities import Entity, Property
 
 from .maputils import SimpleCreateAction
 from ..utils.kabaret.flow_entities.entities import EntityView
-from ..utils.flow.process_files import PlaySequenceAction
+from ..utils.flow.process_files import PlaySequenceAction, PlaySequenceActionFromShot
 
 
 class Shot(Entity):
@@ -16,10 +16,13 @@ class Shot(Entity):
 
     ICON = ('icons.flow', 'shot')
 
+    play_sequence = flow.Child(PlaySequenceActionFromShot).ui(hidden=True)
+
     @classmethod
     def get_source_display(cls, oid):
         split = oid.split('/')
-        return f'{split[3]} · {split[5]} · {split[7]}'
+        indices = list(range(len(split) - 1, 2, -2))
+        return ' · '.join([split[i] for i in reversed(indices)])
 
     def get_default_contextual_edits(self, context_name):
         if context_name == 'settings':
@@ -66,7 +69,8 @@ class Sequence(Entity):
     @classmethod
     def get_source_display(cls, oid):
         split = oid.split('/')
-        return f'{split[3]} · {split[5]}'
+        indices = list(range(len(split) - 1, 2, -2))
+        return ' · '.join([split[i] for i in reversed(indices)])
 
     def get_default_contextual_edits(self, context_name):
         if context_name == 'settings':
