@@ -40,7 +40,8 @@ class Task(Entity):
     @classmethod
     def get_source_display(cls, oid):
         split = oid.split('/')
-        return f'{split[3]} · {split[5]} · {split[7]} · {split[9]}'
+        indices = list(range(len(split) - 1, 2, -2))
+        return ' · '.join([split[i] for i in reversed(indices)])
     
     def get_default_contextual_edits(self, context_name):
         if context_name == 'settings':
