@@ -651,6 +651,10 @@ class DefaultTask(flow.Object):
     icon         = flow.Param()
     files        = flow.Child(DefaultTaskFiles).ui(expanded=True)
 
+    subtasks     = flow.OrderedStringSetParam()
+
+    assignation_enabled = flow.BoolParam(True)
+
     def get_color(self):
         color = self.color.get()
 
@@ -813,6 +817,7 @@ class DefaultTaskView(flow.DynamicMap):
     collection appear greyed out.
     '''
 
+    _action = flow.Parent()
     _tasks = flow.Parent(2)
 
     def __init__(self, parent, name):
@@ -832,7 +837,7 @@ class DefaultTaskView(flow.DynamicMap):
             or self._cache_key != cache_key
         ):
             mgr = self.root().project().get_task_manager()
-            default_tasks = mgr.default_tasks.mapped_items()
+            default_tasks = self._tasks.get_default_tasks()
 
             self._cache = {}
             self._cache_names = []
@@ -962,6 +967,20 @@ class TaskManager(flow.Object):
     def get_task_display_name(self, task_name):
         dt = self.default_tasks[task_name]
         return dt.get_display_name()
+    
+    def get_template_default_tasks(self, template_name):
+        return [
+            dt for dt in self.default_tasks.mapped_items()
+            if dt.template.get() == template_name
+        ]
+    
+    def get_subtasks(self, task_name):
+        dt = self.default_tasks[task_name]
+        return dt.subtasks.get()
+    
+    def is_assignation_enabled(self, task_name):
+        dt = self.default_tasks[task_name]
+        return dt.assignation_enabled.get()
 
     def get_task_files(self, task_name, enabled_only=False):
         """
